@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,16 +18,16 @@
 
 #include "minigui.h"
 #include "widgetactions.h"
-#include "floatingwidget.h"
+#include "autohidewidget.h"
 #include "myaction.h"
 #include "mplayerwindow.h"
 #include "global.h"
 #include "helper.h"
-#include "toolbareditor.h"
 #include "desktopinfo.h"
-
-#include <QToolBar>
+#include "editabletoolbar.h"
+#include "images.h"
 #include <QStatusBar>
+#include <QMenu>
 
 using namespace Global;
 
@@ -37,12 +37,14 @@ MiniGui::MiniGui( QWidget * parent, Qt::WindowFlags flags )
 	createActions();
 	createControlWidget();
 	createFloatingControl();
+	populateMainMenu();
 
-	connect( this, SIGNAL(cursorNearBottom(QPoint)),
-             this, SLOT(showFloatingControl(QPoint)) );
-
-	connect( this, SIGNAL(cursorFarEdges()),
-             this, SLOT(hideFloatingControl()) );
+#if USE_CONFIGURABLE_TOOLBARS
+	connect( editControlAct, SIGNAL(triggered()), controlwidget, SLOT(edit()) );
+	EditableToolbar * iw = static_cast<EditableToolbar *>(floating_control->internalWidget());
+	iw->takeAvailableActionsFrom(this);
+	connect( editFloatingControlAct, SIGNAL(triggered()), iw, SLOT(edit()) );
+#endif
 
 	statusBar()->hide();
 
@@ -53,37 +55,61 @@ MiniGui::MiniGui( QWidget * parent, Qt::WindowFlags flags )
 	if (pref->compact_mode) {
 		controlwidget->hide();
 	}
+
+	applyStyles();
 }
 
 MiniGui::~MiniGui() {
 	saveConfig();
 }
 
+#if USE_CONFIGURABLE_TOOLBARS
+QMenu * MiniGui::createPopupMenu() {
+	QMenu * m = new QMenu(this);
+	m->addAction(editControlAct);
+	m->addAction(editFloatingControlAct);
+	return m;
+}
+#endif
+
 void MiniGui::createActions() {
 	timeslider_action = createTimeSliderAction(this);
-	timeslider_action->disable();
 
 #if USE_VOLUME_BAR
 	volumeslider_action = createVolumeSliderAction(this);
-	volumeslider_action->disable();
 #endif
 
-	time_label_action = new TimeLabelAction(this);
+#if AUTODISABLE_ACTIONS
+	timeslider_action->disable();
+	#if USE_VOLUME_BAR
+	volumeslider_action->disable();
+	#endif
+#endif
+
+	time_label_action = createTimeLabelAction(TimeLabelAction::CurrentAndTotalTime, this);
 	time_label_action->setObjectName("timelabel_action");
 
-	connect( this, SIGNAL(timeChanged(QString)),
-             time_label_action, SLOT(setText(QString)) );
+#if USE_CONFIGURABLE_TOOLBARS
+	editControlAct = new MyAction( this, "edit_control_minigui" );
+	editFloatingControlAct = new MyAction( this, "edit_floating_control_minigui" );
+#endif
 }
 
 
 void MiniGui::createControlWidget() {
-	controlwidget = new QToolBar( this );
+	controlwidget = new EditableToolbar( this );
 	controlwidget->setObjectName("controlwidget");
+	controlwidget->setLayoutDirection(Qt::LeftToRight);
 	controlwidget->setMovable(true);
 	controlwidget->setAllowedAreas(Qt::TopToolBarArea | Qt::BottomToolBarArea);
 	addToolBar(Qt::BottomToolBarArea, controlwidget);
 
-#if !USE_CONFIGURABLE_TOOLBARS
+#if USE_CONFIGURABLE_TOOLBARS
+	QStringList controlwidget_actions;
+	controlwidget_actions << "play_or_pause" << "stop" << "separator" << "timeslider_action" << "separator"
+                          << "fullscreen" << "mute" << "volumeslider_action";
+	controlwidget->setDefaultActions(controlwidget_actions);
+#else
 	controlwidget->addAction(playOrPauseAct);
 	controlwidget->addAction(stopAct);
 	controlwidget->addSeparator();
@@ -91,38 +117,64 @@ void MiniGui::createControlWidget() {
 	controlwidget->addSeparator();
 	controlwidget->addAction(fullscreenAct);
 	controlwidget->addAction(muteAct);
-
-#if USE_VOLUME_BAR
+	#if USE_VOLUME_BAR
 	controlwidget->addAction(volumeslider_action);
-#endif
-
+	#endif
 #endif // USE_CONFIGURABLE_TOOLBARS
 }
 
 void MiniGui::createFloatingControl() {
 	// Floating control
-	floating_control = new FloatingWidget(this);
+	floating_control = new AutohideWidget(mplayerwindow);
+	floating_control->setAutoHide(true);
+
+	EditableToolbar * iw = new EditableToolbar(floating_control);
+	iw->setObjectName("floating_control");
+	connect(iw, SIGNAL(iconSizeChanged(const QSize &)), this, SLOT(adjustFloatingControlSize()));
+
+#if USE_CONFIGURABLE_TOOLBARS
+	QStringList floatingcontrol_actions;
+	floatingcontrol_actions << "play_or_pause" << "stop" << "separator" << "timeslider_action" << "separator"
+                            << "fullscreen" << "mute";
+	#if USE_VOLUME_BAR
+	floatingcontrol_actions << "volumeslider_action";
+	#endif
+	floatingcontrol_actions << "separator" << "timelabel_action";
+	iw->setDefaultActions(floatingcontrol_actions);
+#else
+	iw->addAction(playOrPauseAct);
+	iw->addAction(stopAct);
+	iw->addSeparator();
+	iw->addAction(timeslider_action);
+	iw->addSeparator();
+	iw->addAction(fullscreenAct);
+	iw->addAction(muteAct);
+	#if USE_VOLUME_BAR
+	iw->addAction(volumeslider_action);
+	#endif
+#endif // USE_CONFIGURABLE_TOOLBARS
+
+	floating_control->setInternalWidget(iw);
 
 #if !USE_CONFIGURABLE_TOOLBARS
-	floating_control->toolbar()->addAction(playOrPauseAct);
-	floating_control->toolbar()->addAction(stopAct);
-	floating_control->toolbar()->addSeparator();
-	floating_control->toolbar()->addAction(timeslider_action);
-	floating_control->toolbar()->addSeparator();
-	floating_control->toolbar()->addAction(fullscreenAct);
-	floating_control->toolbar()->addAction(muteAct);
-#if USE_VOLUME_BAR
-	floating_control->toolbar()->addAction(volumeslider_action);
+	floating_control->adjustSize();
 #endif
 
-	floating_control->adjustSize();
-#endif // USE_CONFIGURABLE_TOOLBARS
+	floating_control->hide();
 }
 
 void MiniGui::retranslateStrings() {
 	BaseGuiPlus::retranslateStrings();
 
+	// Change the icon of the play/pause action
+	playOrPauseAct->setIcon(Images::icon("play"));
+
 	controlwidget->setWindowTitle( tr("Control bar") );
+
+#if USE_CONFIGURABLE_TOOLBARS
+	editControlAct->change( tr("Edit &control bar") );
+	editFloatingControlAct->change( tr("Edit &floating control") );
+#endif
 }
 
 #if AUTODISABLE_ACTIONS
@@ -145,9 +197,27 @@ void MiniGui::disableActionsOnStop() {
 }
 #endif // AUTODISABLE_ACTIONS
 
+void MiniGui::togglePlayAction(Core::State state) {
+	qDebug("MiniGui::togglePlayAction");
+	BaseGui::togglePlayAction(state);
+
+	if (state == Core::Playing) {
+		playOrPauseAct->setIcon(Images::icon("pause"));
+	} else {
+		playOrPauseAct->setIcon(Images::icon("play"));
+	}
+}
+
 void MiniGui::aboutToEnterFullscreen() {
 	BaseGuiPlus::aboutToEnterFullscreen();
 
+	floating_control->setMargin(pref->floating_control_margin);
+	floating_control->setPercWidth(pref->floating_control_width);
+	floating_control->setAnimated(pref->floating_control_animated);
+	floating_control->setActivationArea( (AutohideWidget::Activation) pref->floating_activation_area);
+	floating_control->setHideDelay(pref->floating_hide_delay);
+	QTimer::singleShot(100, floating_control, SLOT(activate()));
+
 	if (!pref->compact_mode) {
 		controlwidget->hide();
 	}
@@ -156,7 +226,8 @@ void MiniGui::aboutToEnterFullscreen() {
 void MiniGui::aboutToExitFullscreen() {
 	BaseGuiPlus::aboutToExitFullscreen();
 
-	floating_control->hide();
+	floating_control->deactivate();
+	//floating_control->hide();
 
 	if (!pref->compact_mode) {
 		statusBar()->hide();
@@ -178,27 +249,22 @@ void MiniGui::aboutToExitCompactMode() {
 	controlwidget->show();
 }
 
-void MiniGui::showFloatingControl(QPoint /*p*/) {
-#ifndef Q_OS_WIN
-	floating_control->setBypassWindowManager(pref->bypass_window_manager);
-#endif
-	floating_control->setAnimated( pref->floating_control_animated );
-	floating_control->setMargin(pref->floating_control_margin);
-	floating_control->showOver(panel, 
-                               pref->floating_control_width, 
-                               FloatingWidget::Bottom);
-}
-
-void MiniGui::hideFloatingControl() {
-	floating_control->hide();
-}
-
 #if USE_MINIMUMSIZE
 QSize MiniGui::minimumSizeHint() const {
 	return QSize(controlwidget->sizeHint().width(), 0);
 }
 #endif
 
+void MiniGui::adjustFloatingControlSize() {
+	qDebug("MiniGui::adjustFloatingControlSize");
+	//floating_control->adjustSize();
+	QWidget *iw = floating_control->internalWidget();
+	QSize iws = iw->size();
+	QMargins m = floating_control->contentsMargins();
+	int new_height = iws.height() + m.top() + m.bottom();
+	if (new_height < 32) new_height = 32;
+	floating_control->resize(floating_control->width(), new_height);
+}
 
 void MiniGui::saveConfig() {
 	QSettings * set = settings;
@@ -209,14 +275,21 @@ void MiniGui::saveConfig() {
 		qDebug("MiniGui::saveConfig: w: %d h: %d", width(), height());
 		set->setValue( "pos", pos() );
 		set->setValue( "size", size() );
+		set->setValue( "state", (int) windowState() );
 	}
 
 	set->setValue( "toolbars_state", saveState(Helper::qtVersion()) );
 
 #if USE_CONFIGURABLE_TOOLBARS
 	set->beginGroup( "actions" );
-	set->setValue("controlwidget", ToolbarEditor::save(controlwidget) );
-	set->setValue("floating_control", ToolbarEditor::save(floating_control->toolbar()) );
+	set->setValue("controlwidget", controlwidget->actionsToStringList() );
+	EditableToolbar * iw = static_cast<EditableToolbar *>(floating_control->internalWidget());
+	set->setValue("floating_control", iw->actionsToStringList() );
+	set->endGroup();
+
+	set->beginGroup("toolbars_icon_size");
+	set->setValue("controlwidget", controlwidget->iconSize());
+	set->setValue("floating_control", iw->iconSize());
 	set->endGroup();
 #endif
 
@@ -232,39 +305,35 @@ void MiniGui::loadConfig() {
 		QPoint p = set->value("pos", pos()).toPoint();
 		QSize s = set->value("size", size()).toSize();
 
-		if ( (s.height() < 200) && (!pref->use_mplayer_window) ) {
+		if ( (s.height() < 70) && (!pref->use_mplayer_window) ) {
 			s = pref->default_size;
 		}
 
 		move(p);
 		resize(s);
 
+		setWindowState( (Qt::WindowStates) set->value("state", 0).toInt() );
+
 		if (!DesktopInfo::isInsideScreen(this)) {
-			move(0,0);
-			qWarning("MiniGui::loadConfig: window is outside of the screen, moved to 0x0");
+			QPoint tl = DesktopInfo::topLeftPrimaryScreen();
+			move(tl);
+			qWarning("DefaultGui::loadConfig: window is outside of the screen, moved to %d x %d", tl.x(), tl.y());
 		}
 	}
 
 #if USE_CONFIGURABLE_TOOLBARS
-	QList<QAction *> actions_list = findChildren<QAction *>();
-	QStringList controlwidget_actions;
-	controlwidget_actions << "play_or_pause" << "stop" << "separator" << "timeslider_action" << "separator"
-                          << "fullscreen" << "mute" << "volumeslider_action";
-
-	QStringList floatingcontrol_actions;
-	floatingcontrol_actions << "play_or_pause" << "stop" << "separator" << "timeslider_action" << "separator"
-                            << "fullscreen" << "mute";
-#if USE_VOLUME_BAR
-	floatingcontrol_actions << "volumeslider_action";
-#endif
-
-	floatingcontrol_actions << "separator" << "timelabel_action";
-
 	set->beginGroup( "actions" );
-	ToolbarEditor::load(controlwidget, set->value("controlwidget", controlwidget_actions).toStringList(), actions_list );
-	ToolbarEditor::load(floating_control->toolbar(), set->value("floating_control", floatingcontrol_actions).toStringList(), actions_list );
-	floating_control->adjustSize();
+	controlwidget->setActionsFromStringList( set->value("controlwidget", controlwidget->defaultActions()).toStringList() );
+	EditableToolbar * iw = static_cast<EditableToolbar *>(floating_control->internalWidget());
+	iw->setActionsFromStringList( set->value("floating_control", iw->defaultActions()).toStringList() );
 	set->endGroup();
+
+	set->beginGroup("toolbars_icon_size");
+	controlwidget->setIconSize(set->value("controlwidget", controlwidget->iconSize()).toSize());
+	iw->setIconSize(set->value("floating_control", iw->iconSize()).toSize());
+	set->endGroup();
+
+	floating_control->adjustSize();
 #endif
 
 	restoreState( set->value( "toolbars_state" ).toByteArray(), Helper::qtVersion() );
