@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
 */
 
 
-#ifndef _PREFERENCES_H_
-#define _PREFERENCES_H_
+#ifndef PREFERENCES_H
+#define PREFERENCES_H
 
 /* Global settings */
 
@@ -29,6 +29,10 @@
 #include "audioequalizerlist.h"
 #include "assstyles.h"
 
+#ifdef UPDATE_CHECKER
+#include "updatecheckerdata.h"
+#endif
+
 class Recents;
 class URLHistory;
 class Filters;
@@ -43,8 +47,11 @@ public:
                     BelowNormal = 4, Idle = 5 };
 	enum WheelFunction { DoNothing = 1, Seeking = 2, Volume = 4, Zoom = 8,
                          ChangeSpeed = 16 };
+	enum DragFunction { DragDisabled = 0, MoveWindow = 1, Gestures = 2 };
 	enum OptionState { Detect = -1, Disabled = 0, Enabled = 1 };
 	enum H264LoopFilter { LoopDisabled = 0, LoopEnabled = 1, LoopDisabledOnHD = 2 };
+	enum AutoAddToPlaylistFilter { NoFiles = 0, VideoFiles = 1, AudioFiles = 2, MultimediaFiles = 3, ConsecutiveFiles = 4 };
+	enum Streaming { NoStreaming = 0, StreamingAuto = 1, StreamingYT = 2, StreamingYTDL = 3 };
 
 	Q_DECLARE_FLAGS(WheelFunctions, WheelFunction);
 
@@ -53,12 +60,11 @@ public:
 
 	virtual void reset();
 
-#ifndef NO_USE_INI_FILES
 	void save();
 	void load();
-#endif
 
 	double monitor_aspect_double();
+	void setupScreenshotFolder();
 
 
 
@@ -66,17 +72,26 @@ public:
        General
        ******* */
 
+	int config_version;
+
 	QString mplayer_bin;
 	QString vo; // video output
 	QString ao; // audio output
 
 	bool use_screenshot;
+#ifdef MPV_SUPPORT
+	QString screenshot_template;
+	QString screenshot_format;
+#endif
 	QString screenshot_directory;
+#ifdef CAPTURE_STREAM
+	QString capture_directory;
+#endif
 
-	// SMPlayer will remember all media settings for all videos.
-	// This options allow to disable it:
-	bool dont_remember_media_settings; 	// Will not remember anything
-	bool dont_remember_time_pos;		// Will not remember time pos
+	// Possibility to remember all media settings
+	bool remember_media_settings;
+	bool remember_time_pos;
+	bool remember_stream_settings;
 
 	QString audio_lang; 		// Preferred audio language
 	QString subtitle_lang;		// Preferred subtitle language
@@ -87,17 +102,32 @@ public:
 	bool use_soft_video_eq;
 	bool use_slices;
 	int autoq; 	//!< Postprocessing quality
+
+#ifdef ADD_BLACKBORDERS_FS
 	bool add_blackborders_on_fullscreen;
+#endif
 
 #ifdef Q_OS_WIN
+	#ifdef SCREENSAVER_OFF
 	bool turn_screensaver_off;
+	#endif
+	#ifdef AVOID_SCREENSAVER
 	bool avoid_screensaver;
+	#endif
 #else
 	bool disable_screensaver;
 #endif
 
 #ifndef Q_OS_WIN
-	bool disable_video_filters_with_vdpau;
+	struct VDPAU_settings {
+		bool ffh264vdpau;
+		bool ffmpeg12vdpau;
+		bool ffwmv3vdpau;
+		bool ffvc1vdpau;
+		bool ffodivxvdpau;
+		bool ffhevcvdpau;
+		bool disable_video_filters;
+	} vdpau;
 #endif
 
 	// Audio
@@ -112,6 +142,10 @@ public:
 	int volume;
 	bool mute;
 
+	// Global equalizer
+	bool global_audio_equalizer;
+	AudioEqualizerList audio_equalizer;
+
 	bool autosync;
 	int autosync_factor;
 
@@ -119,12 +153,25 @@ public:
 	bool use_mc;
 	double mc_value;
 
+	// When playing a mp4 file, it will use a m4a file for audio if a there's a file with same name but extension m4a
+	bool autoload_m4a;
+	int min_step; //<! Step to increase of decrease the controls for color, contrast, brightness and so on
+
 	// Misc
 	int osd;
+	double osd_scale; // mpv
+	double subfont_osd_scale; // mplayer
 	int osd_delay; //<! Delay in ms to show the OSD.
+#ifdef MPV_SUPPORT
+	bool osd_fractions; //<! Show OSD times with milliseconds.
+#endif
 
 	QString file_settings_method; //!< Method to be used for saving file settings
 
+	bool tablet_mode;
+	#ifdef Q_OS_WIN
+	QString tablet_mode_change_answer;
+	#endif
 
     /* ***************
        Drives (CD/DVD)
@@ -132,6 +179,9 @@ public:
 
 	QString dvd_device;
 	QString cdrom_device;
+#ifdef BLURAY_SUPPORT
+	QString bluray_device;
+#endif
 
 #ifdef Q_OS_WIN
 	bool enable_audiocd_on_windows;
@@ -148,55 +198,57 @@ public:
        Performance
        *********** */
 
+#ifdef Q_OS_WIN
 	int priority;
+#endif
 	bool frame_drop;
 	bool hard_frame_drop;
 	bool coreavc;
 	H264LoopFilter h264_skip_loop_filter;
 	int HD_height; //!< An HD is a video which height is equal or greater than this.
 
+#ifdef OBSOLETE_FAST_AUDIO_CHANGE
 	OptionState fast_audio_change; // If activated, not restart mplayer
+#endif
+
 #if !SMART_DVD_CHAPTERS
 	bool fast_chapter_change;
 #endif
 
 	int threads; //!< number of threads to use for decoding (-lavdopts threads <1-8>)
+	QString hwdec; //!< hardware video decoding (mpv only)
 
+	bool cache_auto;
 	int cache_for_files;
 	int cache_for_streams;
 	int cache_for_dvds;
 	int cache_for_vcds;
 	int cache_for_audiocds;
+#ifdef TV_SUPPORT
 	int cache_for_tv;
+#endif
 
 
 	/* *********
 	   Subtitles
 	   ********* */
 
-	QString font_file;
-	QString font_name;
-	bool use_fontconfig;
 	QString subcp; // -subcp
 	bool use_enca;
 	QString enca_lang;
-	int font_autoscale; // -subfont-autoscale
 	int subfuzziness;
 	bool autoload_sub;
 
 	bool use_ass_subtitles;
+	bool enable_ass_styles;
 	int ass_line_spacing;
 
-	bool use_closed_caption_subs;
 	bool use_forced_subs_only;
 
 	bool sub_visibility;
 
 	bool subtitles_on_screenshots;
 
-	//! Use the new sub_vob, sub_demux and sub_file commands
-	//! instead of sub_select
-	OptionState use_new_sub_commands; 
 	OptionState change_sub_scale_should_restart;
 
 	//! If true, loading an external subtitle will be done
@@ -211,6 +263,9 @@ public:
 
 	//! If false, options requiring freetype won't be used
 	bool freetype_support;
+#ifdef FONTS_HACK
+	bool use_windowsfontdir;
+#endif
 
 
     /* ********
@@ -230,6 +285,7 @@ public:
 	QString monitor_aspect;
 
 	bool use_idx; //!< Use -idx
+	bool use_lavf_demuxer;
 
 	// Let the user pass options to mplayer
 	QString mplayer_additional_options;
@@ -237,16 +293,17 @@ public:
 	QString mplayer_additional_audio_filters;
 
 	// Logs
+#ifdef LOG_MPLAYER
 	bool log_mplayer;
+	bool verbose_log;
+	bool autosave_mplayer_log;
+	QString mplayer_log_saveto;
+#endif
+#ifdef LOG_SMPLAYER
 	bool log_smplayer;
 	QString log_filter;
-	bool verbose_log;
 	bool save_smplayer_log;
-
-    //mplayer log autosaving
-    bool autosave_mplayer_log;
-    QString mplayer_log_saveto;
-    //mplayer log autosaving end
+#endif
 
 #if REPAINT_BACKGROUND_OPTION
 	//! If true, mplayerlayer erases its background
@@ -257,6 +314,11 @@ public:
     //! to play
 	bool use_edl_files;
 
+#ifdef MPLAYER_SUPPORT
+	//! If true it will pass to mplayer the -playlist option
+	bool use_playlist_option;
+#endif
+
 	//! Preferred connection method: ipv4 or ipv6
 	bool prefer_ipv4;
 
@@ -277,6 +339,22 @@ public:
 
 	QString actions_to_run; //!< List of actions to run every time a video loads.
 
+	//! Show file tag in window title
+	bool show_tag_in_window_title;
+
+	int time_to_kill_mplayer;
+
+#ifdef MPRIS2
+	bool use_mpris2;
+#endif
+
+#ifdef MPV_SUPPORT
+	QString mpv_osd_media_info;
+#endif
+#ifdef MPLAYER_SUPPORT
+	QString mplayer_osd_media_info;
+#endif
+
 
 	/* *********
 	   GUI stuff
@@ -293,7 +371,13 @@ public:
 #if STYLE_SWITCHING
 	QString style; 	//!< SMPlayer look
 #endif
-	bool show_motion_vectors;
+
+	bool center_window; //!< Center the main window when playback starts
+	bool center_window_if_outside; //!< Center the main window after an autoresize if it's outside of the screen
+
+#ifdef GLOBALSHORTCUTS
+	bool use_global_shortcuts;
+#endif
 
 	// Function of mouse buttons:
 	QString mouse_left_click_function;
@@ -304,10 +388,11 @@ public:
 	QString mouse_xbutton2_click_function;
 	int wheel_function;
 
-	QFlags<WheelFunctions> wheel_function_cycle;
-
+	WheelFunctions wheel_function_cycle;
 	bool wheel_function_seeking_reverse;
 
+	int drag_function;
+
 	// Configurable seeking
 	int seeking1; // By default 10s
 	int seeking2; // By default 1m
@@ -323,6 +408,13 @@ public:
 	//! percentage (with fractions) instead of time.
 	bool relative_seeking;  
 #endif
+	bool precise_seeking; //! Enable precise_seeking (only available with mpv)
+
+	bool reset_stop; //! Pressing the stop button resets the position
+
+	//! If true, the left click in the video is delayed some ms
+	//! to check if the user double clicked
+	bool delay_left_click;
 
 	QString language;
 	QString iconset;
@@ -341,6 +433,10 @@ public:
 	//! Close the main window when a file or playlist finish
 	bool close_on_finish;
 
+#ifdef AUTO_SHUTDOWN_PC
+	bool auto_shutdown_pc;
+#endif
+
 	QString default_font;
 
 	//!< Pause the current file when the main window is not visible
@@ -367,18 +463,45 @@ public:
 #endif
 
 	bool auto_add_to_playlist; //!< Add files to open to playlist
-	bool add_to_playlist_consecutive_files;
+	AutoAddToPlaylistFilter media_to_add_to_playlist;
+
+#if LOGO_ANIMATION
+	bool animated_logo;
+#endif
 
 
     /* ********
        TV (dvb)
        ******** */
-
+#ifdef TV_SUPPORT
 	bool check_channels_conf_on_startup;
 	int initial_tv_deinterlace;
 	QString last_dvb_channel;
 	QString last_tv_channel;
-	
+#endif
+
+
+    /* ********
+       Network
+       ******** */
+
+	// Streaming
+	int streaming_type;
+	#ifdef YOUTUBE_SUPPORT
+	int yt_quality;
+	QString yt_user_agent;
+	bool yt_use_https_main;
+	bool yt_use_https_vi;
+	#endif
+
+	// Proxy
+	bool use_proxy;
+	int proxy_type;
+	QString proxy_host;
+	int proxy_port;
+	QString proxy_username;
+	QString proxy_password;
+
 
     /* ***********
        Directories
@@ -386,7 +509,7 @@ public:
 
 	QString latest_dir; //!< Directory of the latest file loaded
 	QString last_dvd_directory;
-
+	bool save_dirs; // Save or not the latest dirs
 
     /* **************
        Initial values
@@ -410,6 +533,10 @@ public:
 	//! 100 = 100% at the bottom
 	int initial_sub_pos;
 
+#ifdef INITIAL_BLACKBORDERS
+	bool initial_blackborders;
+#endif
+
 	bool initial_postprocessing; //!< global postprocessing filter
 	bool initial_volnorm;
 
@@ -432,15 +559,18 @@ public:
 	//! the version can't be parsed from mplayer output
 	int mplayer_user_supplied_version;
 
+#ifdef MPLAYER2_SUPPORT
+	bool mplayer_is_mplayer2; //! True if the detected version is mplayer2
+	QString mplayer2_detected_version;
+#endif
+
 
     /* *********
        Instances
        ********* */
-
+#ifdef SINGLE_INSTANCE
 	bool use_single_instance;
-	int connection_port; // Manual port
-	bool use_autoport;
-	int autoport; // Port automatically chosen by Qt
+#endif
 
 
     /* ****************
@@ -451,9 +581,8 @@ public:
 	int floating_control_width;
 	bool floating_control_animated;
 	bool floating_display_in_compact_mode;
-#ifndef Q_OS_WIN
-	bool bypass_window_manager;
-#endif
+	int floating_activation_area;
+	int floating_hide_delay;
 
 
     /* *******
@@ -468,7 +597,30 @@ public:
        Filters
        ******* */
 	Filters * filters;
+
+
+    /* *********
+       SMPlayer info
+       ********* */
+
+#ifdef CHECK_UPGRADED
+	QString smplayer_stable_version;
+	bool check_if_upgraded;
+#endif
+#ifdef FONTCACHE_DIALOG
+	QString smplayer_version;
+#endif
+
+
+    /* *********
+       Update
+       ********* */
+
+#ifdef UPDATE_CHECKER
+	UpdateCheckerData update_checker_data;
+#endif
 };
+
 Q_DECLARE_OPERATORS_FOR_FLAGS(Preferences::WheelFunctions)
 
 #endif
