@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _PREFERENCESDIALOG_H_
-#define _PREFERENCESDIALOG_H_
+#ifndef PREFERENCESDIALOG_H
+#define PREFERENCESDIALOG_H
 
 #include "ui_preferencesdialog.h"
 
@@ -27,7 +27,7 @@
 #endif
 */
 
-class QTextBrowser;
+class InfoWindow;
 class QPushButton;
 
 class PrefWidget;
@@ -40,6 +40,8 @@ class PrefInput;
 class PrefAdvanced;
 class PrefPlaylist;
 class PrefTV;
+class PrefUpdates;
+class PrefNetwork;
 class PrefAssociations;
 
 class Preferences;
@@ -48,6 +50,7 @@ class Preferences;
 class PreferencesDialog : public QDialog, public Ui::PreferencesDialog
 {
 	Q_OBJECT
+	Q_PROPERTY(bool iconMode READ isIconMode WRITE setIconMode)
 
 public:
 	enum Section { General=0, Drives=1, Performance=2,
@@ -60,6 +63,9 @@ public:
 	PrefInterface * mod_interface() { return page_interface; };
 	PrefInput * mod_input() { return page_input; };
 	PrefAdvanced * mod_advanced() { return page_advanced; };
+	PrefPlaylist * mod_playlist() { return page_playlist; };
+	PrefUpdates * mod_updates() { return page_updates; };
+	PrefNetwork * mod_network() { return page_network; };
 
 	void addSection(PrefWidget *w);
 
@@ -72,6 +78,9 @@ public:
 	// Return true if the mplayer process should be restarted.
 	bool requiresRestart();
 
+	void setIconMode(bool);
+	bool isIconMode() { return icon_mode; };
+
 public slots:
 	void showSection(Section s);
 
@@ -97,20 +106,26 @@ protected:
 	PrefInterface * page_interface;
 	PrefInput * page_input;
 	PrefPlaylist * page_playlist;
+#ifdef TV_SUPPORT
 	PrefTV * page_tv;
+#endif
+	PrefUpdates * page_updates;
+	PrefNetwork * page_network;
 	PrefAdvanced * page_advanced;
 
 #if USE_ASSOCIATIONS
-	PrefAssociations* page_associations; 
+	PrefAssociations* page_associations;
 #endif
 
-	QTextBrowser * help_window;
+	InfoWindow * help_window;
 
 private:
-    QPushButton * okButton;
-    QPushButton * cancelButton;
+	QPushButton * okButton;
+	QPushButton * cancelButton;
 	QPushButton * applyButton;
-    QPushButton * helpButton;
+	QPushButton * helpButton;
+
+	bool icon_mode;
 };
 
 #endif
