@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,10 @@ PrefInput::PrefInput(QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 
+#ifndef GLOBALSHORTCUTS
+	globalshortcuts_check->hide();
+#endif
+
 	retranslateStrings();
 }
 
@@ -39,7 +43,7 @@ QString PrefInput::sectionName() {
 }
 
 QPixmap PrefInput::sectionIcon() {
-    return Images::icon("input_devices");
+	return Images::icon("input_devices");
 }
 
 void PrefInput::createMouseCombos() {
@@ -64,6 +68,8 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->addItem( tr("Go forward (long)"), "forward3" );
 	left_click_combo->addItem( tr("Increase volume"), "increase_volume" );
 	left_click_combo->addItem( tr("Decrease volume"), "decrease_volume" );
+	left_click_combo->addItem( tr("Play next"), "play_next" );
+	left_click_combo->addItem( tr("Play previous"), "play_prev" );
 	left_click_combo->addItem( tr("Fullscreen"), "fullscreen" );
 	left_click_combo->addItem( tr("Compact"), "compact" );
 	left_click_combo->addItem( tr("Screenshot"), "screenshot" );
@@ -79,6 +85,8 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->addItem( tr("Frame counter"), "frame_counter" );
 	left_click_combo->addItem( tr("Preferences"), "show_preferences" );
 	left_click_combo->addItem( tr("Double size"), "toggle_double_size" );
+	left_click_combo->addItem( tr("Next chapter"), "next_chapter" );
+	left_click_combo->addItem( tr("Previous chapter"), "prev_chapter" );
 	left_click_combo->addItem( tr("Show video equalizer"), "video_equalizer" );
 	left_click_combo->addItem( tr("Show audio equalizer"), "audio_equalizer" );
 	left_click_combo->addItem( tr("Show context menu"), "show_context_menu" );
@@ -151,6 +159,15 @@ void PrefInput::retranslateStrings() {
 	wheel_function_volume->setText( tr("&Volume control") );
 	wheel_function_speed->setText( tr("&Change speed") );
 
+	int drag_function = drag_function_combo->currentIndex();
+	drag_function_combo->clear();
+	drag_function_combo->addItem( tr("None"), Preferences::DragDisabled);
+	drag_function_combo->addItem( tr("Move window"), Preferences::MoveWindow);
+#ifdef MOUSE_GESTURES
+	drag_function_combo->addItem( tr("Seek and volume"), Preferences::Gestures);
+#endif
+	drag_function_combo->setCurrentIndex(drag_function);
+
 #if !USE_SHORTCUTGETTER
 	actioneditor_desc->setText( 
 		tr("Here you can change any key shortcut. To do it double click or "
@@ -172,6 +189,13 @@ void PrefInput::setData(Preferences * pref) {
 	setWheelFunction( pref->wheel_function );
 	setWheelFunctionCycle(pref->wheel_function_cycle);
 	setWheelFunctionSeekingReverse(pref->wheel_function_seeking_reverse);
+	delay_left_check->setChecked(pref->delay_left_click);
+
+	setDragFunction(pref->drag_function);
+
+#ifdef GLOBALSHORTCUTS
+	setUseGlobalShortcuts(pref->use_global_shortcuts);
+#endif
 }
 
 void PrefInput::getData(Preferences * pref) {
@@ -186,6 +210,13 @@ void PrefInput::getData(Preferences * pref) {
 	pref->wheel_function = wheelFunction();
 	pref->wheel_function_cycle = wheelFunctionCycle();
 	pref->wheel_function_seeking_reverse = wheelFunctionSeekingReverse();
+	pref->delay_left_click = delay_left_check->isChecked();
+
+	pref->drag_function = dragFunction();
+
+#ifdef GLOBALSHORTCUTS
+	pref->use_global_shortcuts = useGlobalShortcuts();
+#endif
 }
 
 /*
@@ -265,19 +296,19 @@ int PrefInput::wheelFunction() {
 	return wheel_function_combo->itemData(wheel_function_combo->currentIndex()).toInt();
 }
 
-void PrefInput::setWheelFunctionCycle(QFlags<Preferences::WheelFunctions> flags){
+void PrefInput::setWheelFunctionCycle(Preferences::WheelFunctions flags){
 	wheel_function_seek->setChecked(flags.testFlag(Preferences::Seeking));
 	wheel_function_volume->setChecked(flags.testFlag(Preferences::Volume));
 	wheel_function_zoom->setChecked(flags.testFlag(Preferences::Zoom));
 	wheel_function_speed->setChecked(flags.testFlag(Preferences::ChangeSpeed));
 }
 
-QFlags<Preferences::WheelFunctions> PrefInput::wheelFunctionCycle(){
-	QFlags<Preferences::WheelFunctions> seekflags (QFlag ((int) Preferences::Seeking)) ;
-	QFlags<Preferences::WheelFunctions> volumeflags (QFlag ((int) Preferences::Volume)) ;
-	QFlags<Preferences::WheelFunctions> zoomflags (QFlag ((int) Preferences::Zoom)) ;
-	QFlags<Preferences::WheelFunctions> speedflags (QFlag ((int) Preferences::ChangeSpeed)) ;
-	QFlags<Preferences::WheelFunctions> out (QFlag (0));
+Preferences::WheelFunctions PrefInput::wheelFunctionCycle(){
+	Preferences::WheelFunctions seekflags (QFlag ((int) Preferences::Seeking)) ;
+	Preferences::WheelFunctions volumeflags (QFlag ((int) Preferences::Volume)) ;
+	Preferences::WheelFunctions zoomflags (QFlag ((int) Preferences::Zoom)) ;
+	Preferences::WheelFunctions speedflags (QFlag ((int) Preferences::ChangeSpeed)) ;
+	Preferences::WheelFunctions out (QFlag (0));
 	if(wheel_function_seek->isChecked()){
 		out = out | seekflags;
 	}
@@ -301,6 +332,26 @@ bool PrefInput::wheelFunctionSeekingReverse() {
 	return wheel_function_seeking_reverse_check->isChecked();
 }
 
+void PrefInput::setDragFunction(int function) {
+	int d = drag_function_combo->findData(function);
+	if (d < 0) d = 0;
+	drag_function_combo->setCurrentIndex( d );
+}
+
+int PrefInput::dragFunction() {
+	return drag_function_combo->itemData(drag_function_combo->currentIndex()).toInt();
+}
+
+#ifdef GLOBALSHORTCUTS
+void PrefInput::setUseGlobalShortcuts(bool b) {
+	globalshortcuts_check->setChecked(b);
+}
+
+bool PrefInput::useGlobalShortcuts() {
+	return globalshortcuts_check->isChecked();
+}
+#endif
+
 void PrefInput::createHelp() {
 	clearHelp();
 
@@ -317,6 +368,12 @@ void PrefInput::createHelp() {
            "keys). If the <b>Capture</b> button is off "
            "then you could enter the full name of the key.") );
 
+#ifdef GLOBALSHORTCUTS
+	setWhatsThis(globalshortcuts_check, tr("Use the multimedia keys as global shortcuts"),
+		tr("When this option is enabled the multimedia keys (Play, Stop, Volume+/-, Mute, etc.) "
+           "will work even when SMPlayer is running in the background."));
+#endif
+
 	addSectionTitle(tr("Mouse"));
 
 	setWhatsThis(left_click_combo, tr("Left click"),
@@ -337,6 +394,25 @@ void PrefInput::createHelp() {
 	setWhatsThis(wheel_function_combo, tr("Wheel function"),
 		tr("Select the action for the mouse wheel.") );
 
+	setWhatsThis(drag_function_combo, tr("Drag function"),
+		tr("This option controls what to do when the mouse is moved while pressing the left button.") + "<br>" +
+		"<b>" + tr("Move window") + "</b>:" + tr("the main window is moved") + "<br>"
+#ifdef MOUSE_GESTURES
+		+ "<b>" + tr("Seek and volume") + "</b>:" +
+		tr("a horizontal movement changes the time position while a vertical movement changes the volume")
+#endif
+	);
+
+	setWhatsThis(delay_left_check, tr("Don't trigger the left click function with a double click"),
+		tr("If this option is enabled when you double click on the "
+            "video area only the double click function will be triggered. "
+            "The left click action won't be activated.") + " "+
+		tr("By enabling this option the left click is delayed %1 milliseconds "
+           "because it's necessary to wait that time to know if there's a double click or not.").arg(qApp->doubleClickInterval()+10) );
+
+	setWhatsThis(wheel_function_seeking_reverse_check, tr("Reverse mouse wheel seeking"),
+		tr("Check it to seek in the opposite direction.") );
+
 	addSectionTitle(tr("Mouse wheel functions"));
 
 	setWhatsThis(wheel_function_seek, tr("Media seeking"),
@@ -350,10 +426,6 @@ void PrefInput::createHelp() {
 
 	setWhatsThis(wheel_function_speed, tr("Change speed"),
 		tr("Check it to enable changing speed as one function.") );
-
-	setWhatsThis(wheel_function_seeking_reverse_check, tr("Reverse mouse wheel seeking"),
-		tr("Check it to seek in the opposite direction.") );
-
 }
 
 #include "moc_prefinput.cpp"
